use strict;
use warnings;

package App::PM::Website;
{
  $App::PM::Website::VERSION = '0.122450';
}
#use App::Cmd::Setup -app;
use base 'App::Cmd';


#ABSTRACT: tools for maintaining a perl mongers (webDav) website

1;

__END__
=pod

=head1 NAME

App::PM::Website - tools for maintaining a perl mongers (webDav) website

=head1 VERSION

version 0.122450

=head1 AUTHOR

Andrew Grangaard <spazm@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2012 by Andrew Grangaard.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut

